<?php
/*
 * Copyright(c) 2015 PAYDESIGN, Inc. All rights reserved.
 * http://www.paydesign.co.jp/
 */

namespace Plugin\PayDesign\ServiceProvider;

use Silex\Application as BaseApplication;
use Silex\ServiceProviderInterface;

class PayDesignServiceProvider implements ServiceProviderInterface
{
    public function register(BaseApplication $app)
    {
        // Frontpage
        // Mypage
        $app->match('/mypage/credit', '\\Plugin\\PayDesign\\Controller\\MypageController::credit_index')->bind('paydesign_mypage_credit');
        $app->match('/mypage/credit_complete', '\\Plugin\\PayDesign\\Controller\\MypageController::credit_complete')->bind('paydesign_mypage_credit_complete');
        $app->match('/mypage/credit_delete_complete', '\\Plugin\\PayDesign\\Controller\\MypageController::credit_delete_complete')->bind('paydesign_mypage_credit_delete_complete');
        $app->match('/mypage/periodic', '\\Plugin\\PayDesign\\Controller\\MypageController::periodic_index')->bind('paydesign_mypage_periodic');
        $app->match('/mypage/periodic/{id}/edit', '\\Plugin\\PayDesign\\Controller\\MypageController::periodic_edit')->bind('paydesign_mypage_periodic_edit');
        $app->match('/mypage/periodic_complete', '\\Plugin\\PayDesign\\Controller\\MypageController::periodic_complete')->bind('paydesign_mypage_periodic_complete');

        // Credit Protocol (Mypage)
        $app->match('/mypage/paydesign/linkCardUpdateResult', '\\Plugin\\PayDesign\\Controller\\CreditController::mypage_link_card_update_result')->bind('paydesign_mypage_link_card_update_result');
        $app->match('/mypage/paydesign/linkCardUpdateCancel', '\\Plugin\\PayDesign\\Controller\\CreditController::mypage_link_card_update_cancel')->bind('paydesign_mypage_link_card_update_cancel');

        // Credit Protocol (Shopping)
        $app->match('/shopping/paydesign/cancel', '\\Plugin\\PayDesign\\Controller\\CreditController::cancel')->bind('paydesign_shopping_credit_cancel');
        $app->match('/shopping/paydesign/result', '\\Plugin\\PayDesign\\Controller\\CreditController::result')->bind('paydesign_shopping_credit_result');
        $app->match('/shopping/paydesign/linkResult', '\\Plugin\\PayDesign\\Controller\\CreditController::linkResult')->bind('paydesign_shopping_credit_link_result');
        $app->match('/shopping/paydesign/creditComplete', '\\Plugin\\PayDesign\\Controller\\CreditController::creditComplete')->bind('paydesign_shopping_credit_complete');

        // Convenience Protocol
        $app->match('/shopping/paydesign/convenience', '\\Plugin\\PayDesign\\Controller\\ConvenienceController::index')->bind('paydesign_shopping_convenience');
        $app->match('/shopping/paydesign/convenience/complete', '\\Plugin\\PayDesign\\Controller\\ConvenienceController::complete')->bind('paydesign_shopping_convenience_complete');
        $app->match('/shopping/paydesign/convenience/back', '\\Plugin\\PayDesign\\Controller\\ConvenienceController::back')->bind('paydesign_shopping_convenience_back');
        $app->match('/shopping/paydesign/convPaymentResult', '\\Plugin\\PayDesign\\Controller\\ConvenienceController::convPaymentResult')->bind('paydesign_shopping_convenience_payment_result');
        $app->match('/shopping/paydesign/convCancelResult', '\\Plugin\\PayDesign\\Controller\\ConvenienceController::convCancelResult')->bind('paydesign_shopping_convenience_cancel_result');

        // Admin
        // Periodic
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic', '\\Plugin\\PayDesign\\Controller\\PeriodicController::index')->bind('plugin_PayDesign_periodic');
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic/page/{page_no}', '\\Plugin\\PayDesign\\Controller\\PeriodicController::index')->assert('page_no', '\d+')->bind('plugin_PayDesign_periodic_page');
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic/{id}/edit', '\\Plugin\\PayDesign\\Controller\\PeriodicController::edit')->bind('plugin_PayDesign_periodic_edit');
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic/{id}/delete', '\\Plugin\\PayDesign\\Controller\\PeriodicController::delete')->bind('plugin_PayDesign_periodic_delete');
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic/export', '\\Plugin\\PayDesign\\Controller\\PeriodicController::exportCsv')->bind('plugin_PayDesign_periodic_export_csv');
        $app->match('/' . $app["config"]["admin_route"] . '/order/periodic_create', '\\Plugin\\PayDesign\\Controller\\PeriodicController::create_index')->bind('plugin_PayDesign_periodic_create');

        // Plugin Setting
        $app->match('/' . $app["config"]["admin_route"] . '/plugin/paydesign/config', '\\Plugin\\PayDesign\\Controller\\ConfigController::edit')->bind('plugin_PayDesign_config');

        // Periodic Make Order Batch
        // セキュリティ用パラメータ（乱数）：mSuldeOaEAAZUCbzYXyNTiCcCoyjCuxantYJvUGIYVqrvqESQVLVpPISbAHvOUtI
        $app->match('/plugin/paydesign/batch/periodic/mSuldeOaEAAZUCbzYXyNTiCcCoyjCuxantYJvUGIYVqrvqESQVLVpPISbAHvOUtI', '\\Plugin\\PayDesign\\Controller\\PeriodicController::PeriodicMakeOrder')->bind('plugin_PayDesign_periodic_make_order');
        // Repository Setting
        // 注文拡張情報
        $app['eccube.plugin.paydesign.repository.paydesign_order_info'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignOrderInfo');
        });
        // プラグイン情報
        $app['eccube.plugin.paydesign.repository.paydesign_plugin'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignPlugin');
        });
        // 支払方法拡張情報
        $app['eccube.plugin.paydesign.repository.paydesign_payment_method'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignPaymentMethod');
        });
        // 商品情報 拡張定期情報
        $app['eccube.plugin.paydesign.repository.paydesign_product_periodic_info'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignProductPeriodicInfo');
        });
        // 会員カード情報
        $app['eccube.plugin.paydesign.repository.paydesign_card_info'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignCardInfo');
        });
        // 会員カード変更(オーダー)情報
        $app['eccube.plugin.paydesign.repository.paydesign_card_order'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignCardOrder');
        });
        // 定期情報
        $app['eccube.plugin.paydesign.repository.paydesign_periodic_info'] = $app->share(function () use ($app) {
            return $app['orm.em']->getRepository('Plugin\PayDesign\Entity\PayDesignPeriodicInfo');
        });

        // FormType Setting
        $app['form.types'] = $app->share($app->extend('form.types', function ($types) use ($app) {
            $types[] = new \Plugin\PayDesign\Form\Type\AdminSearchPeriodicType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\AdminSearchPeriodicCreateType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\AdminProductPeriodicInfoType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\AdminPeriodicInfoEditType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\ProductClassCustomType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\ConfigType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\MypageCreditType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\MypagePeriodicType($app);
            $types[] = new \Plugin\PayDesign\Form\Type\ConvenienceType($app);
            return $types;
        }));

        // サブナビの拡張（メニューの設定）
        $app['config'] = $app->share($app->extend('config', function ($config) {
            $addNavi['id'] = "periodic";
            $addNavi['name'] = "定期管理";

            $addNavi['has_child'] = 'true';
            $addNavi['child'] = array(
                array(
                    'id' => 'periodic_master',
                    'url' => 'plugin_PayDesign_periodic',
                    'name' => '定期マスター',
                ),
                array(
                    'id' => 'periodic_create',
                    'url' => 'plugin_PayDesign_periodic_create',
                    'name' => '定期注文データ作成',
                ),
            );

            $nav = $config['nav'];
            foreach ($nav as $key => $val) {
                if ("order" == $val["id"]) {
                    $nav[$key]['child'][] = $addNavi;
                }
            }

            $config['nav'] = $nav;
            return $config;
        }));
    }

    public function boot(BaseApplication $app)
    {
    }
}
?>
